# sortedl1

```{toctree}
:maxdepth: 2
:hidden:
:caption: Contents

Home<self>
getting-started
api
changelog
```

Welcome to the documentation for **sortedl1**! This package provides estimators for fitting generalized linear models regularized with the sorted l1 norm.

## Installing

**sortedl1** is available on PyPI and can be installed via pip by running

```python
pip install sortedl1
```
